/* Constructing data from IMS */

global disk E

use "$disk:\IMS\2014\Toulouse - US Drugstores.dta", clear
foreach q in 03 06 09 12 {
foreach y of numlist 2002/2014  {
capture rename sales_mnf_qtr_`q'_`y'_lcus_dolla  sales_`y'`q'  
capture rename standard_units_qtr_`q'_`y'_1000 su_`y'`q'  
capture rename units_qtr_`q'_`y'_1000 u_`y'`q'  
}
}
drop     sales_trd* sales_pub* sales_mnf* standard_units* units_mat*
keep if atc4=="C10A1 (STATINS (HMG-COA RED)   ) "
gen id=_n
qui compress
reshape long sales_ su_ u_ , i(id) j(quarter)
keep if atc4=="C10A1 (STATINS (HMG-COA RED)   ) " & sales_>0
tab corporation
collapse (sum) sales_ su_ u_ , by(molecule corporation brandedvsgeneric quarter strength intprd loe)
gen sector="retail"
compress
save "$disk:\dropbox\parallel\data\statins_us_drugstores.dta" , replace
use "$disk:\IMS\2014\Toulouse - France Retail.dta" , clear
foreach q in 03 06 09 12 {
foreach y of numlist 2002/2014  {
capture rename sales_mnf_qtr_`q'_`y'_lcus_dolla  sales_`y'`q'  
capture rename standard_units_qtr_`q'_`y'_1000 su_`y'`q'  
capture rename units_qtr_`q'_`y'_1000 u_`y'`q'  
}
}
drop     sales_trd* sales_pub* sales_mnf* standard_units* units_mat*
keep if atc4=="C10A1 (STATINS (HMG-COA RED)   ) "
gen id=_n
qui compress
reshape long sales_ su_ u_ , i(id) j(quarter)
*save "$disk:\IMS\2014\Toulouse - France Retail long.dta" , replace
keep if atc4=="C10A1 (STATINS (HMG-COA RED)   ) " & sales_>0
tab corporation
collapse (sum) sales_ su_ u_ , by(molecule corporation brandedvsgeneric quarter strength intprd loe)
gen sector="retail"
save "$disk:\dropbox\parallel\data\statins_france.dta" , replace
use "$disk:\IMS\2014\Toulouse - France Hospital.dta" , clear
foreach q in 03 06 09 12 {
foreach y of numlist 2002/2014  {
capture rename sales_mnf_qtr_`q'_`y'_lcus_dolla  sales_`y'`q'  
capture rename standard_units_qtr_`q'_`y'_1000 su_`y'`q'  
capture rename units_qtr_`q'_`y'_1000 u_`y'`q'  
}
}
drop     sales_trd* sales_pub* sales_mnf* standard_units* units_mat*
keep if atc4=="C10A1 (STATINS (HMG-COA RED)   ) "
gen id=_n
qui compress
reshape long sales_ su_ u_ , i(id) j(quarter)
*save "$disk:\IMS\2014\Toulouse - France Retail long.dta" , replace
keep if atc4=="C10A1 (STATINS (HMG-COA RED)   ) " & sales_>0
collapse (sum) sales_ su_ u_ , by(molecule corporation brandedvsgeneric quarter strength intprd loe)
append using  "$disk:\dropbox\parallel\data\statins_france.dta" 
replace sector="hospital" if sector==""
compress
save "$disk:\dropbox\parallel\data\statins_france.dta" , replace

/* Creating US prices IVS */
use "$disk:\dropbox\parallel\data\statins_us_drugstores.dta"
drop if su_==0 /* 16 obs */
keep if strength=="0040MG"|strength=="0080MG"|strength=="0020MG"|strength=="0010MG"
gen corp=corporation
replace corp="generic" if brandedvsgeneric=="GENERIC PRODUCTS"
collapse (sum) sales_ su_ u_, by(quarter molecule strength sector corp loe)
gen year=int(quarter/100)
gen price=sales_/su_
gen generic=corp=="generic"
egen id=group(molecule generic strength corp)
gen price_retail_US=price if (sector=="retail")
keep quarter molecule  corp strength  res_price_retail_US price_retail_US
save "$disk:\dropbox\parallel\data\IVs_statins_us_drugstores.dta",replace


/******* Demand estimation ***********/
use "$disk:\dropbox\parallel\data\statins_france.dta" , clear
gen corp=corporation
replace corp="generic" if brandedvsgeneric=="GENERIC PRODUCTS"
collapse (sum) sales_ su_ u_, by(quarter molecule strength sector corp loe)
merge m:1 quarter molecule  corp  strength  using "$disk:\dropbox\parallel\data\IVs_statins_us_drugstores.dta"
drop if _merge==2  /* all statins in the US but not in France */ 
drop if su_==0 /* 6 obs */
drop if strength=="00.1MG" /* 1 obs */
drop if strength=="00.3MG" /* 1 obs */
drop if strength=="0005MG" /* 186 obs */
global outside_good=0.5   /*  s_0=outside_good/(1+outside_good)  */
egen totalsu=sum(su_), by(strength sector quarter)
gen share=su_/(totalsu*(1+$outside_good))
gen logshare=log(share)-log($outside_good/(1+$outside_good))
gen year=int(quarter/100)
gen price=sales_/su_
gen generic=corp=="generic"
egen id=group(molecule generic strength corp )
gen logprice=log(price)

foreach s in hospital   {
egen IV_price_`s'=max(price_`s') , by(molecule strength corp quarter)
egen temp=max(price_`s') , by(molecule strength generic quarter)
replace IV_price_`s'=temp if IV_price_`s'==.
drop temp
egen temp=max(price_`s') , by(molecule strength quarter)
replace IV_price_`s'=temp if IV_price_hospital==.
drop temp
egen temp=max(price_`s') , by(molecule strength year)
replace IV_price_`s'=temp if IV_price_`s'==.
drop temp
}

/* US IVs */
egen nb_drugs_US=count(price_retail_US) , by(molecule strength quarter)
foreach var in  price_retail_US {
egen IV_`var'=mean(`var'),by(molecule strength corp quarter)
egen tmp=max(`var'),by(molecule strength generic quarter)
replace IV_`var'=tmp if IV_`var'==.
drop tmp
egen tmp=max(`var') , by(molecule strength quarter)
replace IV_`var'=tmp if IV_`var'==.
drop tmp
egen tmp=max(`var') , by(molecule strength year)
replace IV_`var'=tmp if IV_`var'==.
drop tmp
}
egen IV_nbdrugs=count(su_), by(molecule strength quarter )
egen IV_nbgeneric=sum(generic), by(molecule strength quarter )
tab molecule,gen(mol)
foreach i of numlist 1/5 {
gen mol`i'gen=mol`i'*generic
gen mol`i'brand=mol`i'*(1-generic)
}
tab strength,gen(strength)
tab year,gen(y_)
gen cons=1
gen sjt=exp(logshare+log($outside_good/(1+$outside_good)))

levelsof molecule if sector=="retail" & year<2008 & year>=2004,local(moleculelist) 
foreach m in `moleculelist' {
gen mol_`m'=(molecule=="`m'")
}
qui compress
 
/* BLP */
keep if strength=="0080MG" | strength=="0040MG" | strength=="0020MG"  
egen num_mkt=group(sector quarter strength)
egen mol_strfe=group(molecule strength)
tab mol_strfe,gen(molstr_)
drop mol_strfe
gen molecule_loe=0
replace molecule_loe=1 if quarter>200808 & molecule=="FLUVASTATIN"
replace molecule_loe=1 if quarter>201706 & molecule=="ROSUVASTATIN"
replace molecule_loe=1 if quarter>200608 & molecule=="PRAVASTATIN "
replace molecule_loe=1 if quarter>200505 & molecule=="SIMVASTATIN"
replace molecule_loe=1 if quarter>201205 & molecule=="ATORVASTATIN"
keep if sector=="retail"

sort num_mkt
 
levelsof molecule,local(mollist)
foreach var in IV_price_retail_US IV_nbdrugs {
foreach mol in `mollist' {
	gen `mol'`var'=(molecule=="`mol'")*`var'
}
}
tab quarter,gen(q_)

global listIV "IV_price_hospital IV_price_retail_US IV_nbdrugs IV_nbgeneric" 
di "$listIV"
global listx "mol_*  y_4 y_5 y_6   strength3 strength4    molecule_loe "  
xi: reg price $listx $listIV  i.year*IV_price_hospital  if  year<2008 & year>=2004 
xi: reg price molstr_1-molstr_8  q_8-q_22        molecule_loe $listx $listIV     if  year<2008 & year>=2004 

xi : blp share molstr_1-molstr_8 q_8-q_22 molecule_loe if year<2008 & year>=2004  , stochastic(price) endog(price = $listIV ) markets(num_mkt)    optinst($listIV )  
global listx "molstr_1-molstr_8 q_8-q_22 molecule_loe"  
di "$listIV"
mat b=e(b)
mat V=e(V)
predict xb
svmat b , names(b) 
estimates store blp
 
/* contraction mapping */
gen delta=log(share)-xb 
sum delta 
gen obs_id=_n
expand 200  , gen(tag)
bysort obs_id : gen expand=_n
set seed 2
drawnorm w1 
egen vv1=max(w1) if obs_id==1,by(expand)
egen v1=mean(vv1),by(expand)
drop vv1 
compress
preserve
keep v1 
duplicates drop
save "$disk:\Dropbox\parallel\data\blp_draws",replace 
restore
gen muijt=v1*[#2]_b[SD]*price 
gen betai=[#1]_b[price]+v1*[#2]_b[SD]

foreach i of numlist 1/100 { /* contraction mapping */
qui gen sijt=exp(xb+muijt+delta)
qui egen tmp=sum(sijt),by(quarter strength expand)
qui replace sijt=sijt/((1+tmp))
qui egen s_jt= mean(sijt), by(obs_id)
qui sum delta
qui local delta=r(mean)
qui qui replace delta=delta+ln(share)-ln(s_jt) 
qui sum delta
qui local d=abs(r(mean)-`delta')
di "`d'" /* check convergence */
qui drop sijt s_jt tmp
}
 
egen tmp=sum(exp(xb+muijt+delta)),by(quarter strength expand)
gen tmp0=tmp-exp(xb+muijt+delta)
gen sijt=exp(xb+muijt+delta)/(1+tmp)
egen s_jt= mean(sijt), by(obs_id)
egen wp_jt= mean(sijt), by(obs_id)
egen w_jt= mean(ln(1+tmp)/betai), by(obs_id)
egen w0_jt= mean(ln(1+tmp0)/betai) , by(obs_id)
gen dw_jt=w_jt-w0_jt
gen dwdp=wp_jt/dw_jt
egen ds_jt=mean(betai*sijt*(1-sijt)), by(obs_id)
gen dlnqdp=ds_jt/s_jt
egen elast=mean(betai*price*(1-sijt)), by(obs_id)
sum elast
sum dlnqdp dwdp
global bFR=0.5
keep if tag==0 

gen exp=s_jt*price
gen dexp=s_jt+ds_jt*price
global gamma=1
gen dlnwtcdp=(1/(dw_jt-${gamma}*exp))*(wp_jt-${gamma}*dexp)
gen cost=price+1/(dlnqdp+((1-${bFR})/${bFR})*dlnwtcdp)
sum cost price if year>=2004 & year<2008, d
graph twoway (scatter cost price if cost>0 & cost<price) (scatter price price)
graph twoway (scatter cost price if cost>0 & cost<price & generic==0) (scatter price price if generic==0)

/* estimation of bargaining parameter */ 
encode molecule,gen(moleculeencode)
encode corporation,gen(corporationencode)
sum cost ,d
sum cost if year<2008,d
global listcostvar  "molstr_1-molstr_11 i.quarter "
global listcostvar "i.moleculeencode strength3 strength4 i.quarter "
di "$listcostvar"

xi :  reg cost $listcostvar if generic==0 & molecule!="ATORVASTATIN"  &  year>=2004 & year<2008
global minrss0=e(rss)
gen bFR=_n
gen rss=.  
global minrss=$minrss0*10
global bFR=0.5
global gamma=0
 foreach b of numlist 1/99 { 
qui gen cost_temp= (price+1/(dlnqdp+((100-`b')/`b')*  (1/(dw_jt-${gamma}*exp))*(wp_jt-${gamma}*dexp) )) 
qui  xi:  reg cost_temp $listcostvar  if generic==0 & molecule!="ATORVASTATIN" & sector=="retail"    & year<2008 
if e(rss)<${minrss} {
global  minrss=e(rss)
global bFR=(`b'/100) 
}
qui replace rss=e(rss) if _n==`b'
drop cost_temp 
}
di  $bFR
graph twoway (line rss bFR if rss!=.& rss<100 & _n<=99,sort)
gen bFRoptimal=$bFR
replace cost=price+1/(dlnqdp+((1-$bFR)/$bFR)*dwdp)
gen margin=price-cost
sum margin cost price if generic==0 & molecule!="ATORVASTATIN" & sector=="retail" & year<2008 & year>=2004 

egen price_mol_0=sum(sales_*(generic==0)),by(molecule quarter)
egen t_0=sum(su_*(generic==0)),by(molecule quarter)
replace price_mol_0=price_mol_0/t_0
egen price_mol_1=sum(sales_*(generic==1)),by(molecule quarter)
egen t_1=sum(su_*(generic==1)),by(molecule quarter)
replace price_mol_1=price_mol_1/t_1
gen ratio=price_mol_1/price_mol_0
table quarter molecule  if generic==1 &  year>=2004 & year<2008 & sector=="retail" ,c(mean ratio min ratio max ratio)
gen regul_ratio=0.6
sum share s_jt 

outfile quarter molecule share s_jt  price generic  corp    strength share su_ delta b1-b27 strength num_mkt $listx bFRoptimal using "$disk:\Dropbox\parallel\data\blp_coef"  , replace
keep quarter molecule share s_jt  price generic  corp  strength share su_ delta b1-b27 strength num_mkt $listx bFRoptimal
save "$disk:\Dropbox\parallel\data\blp_coef",replace

/* make table of results */
estout blp using "$disk:\Dropbox\parallel\data\results_blp_france.tex", style(tex) label cells("b(star fmt(4)) se(par fmt(4))") stats(N,  fmt(%9.5f %9.0g) labels(  "N" )) collabels(none) replace 



