clear
set matsize 2000

use "d:\Dropbox\parallel\data\reduced_form_data.dta" 
/*
•	The prescription/transaction data are proprietary, and were obtained from the Norwegian Directorate of Health. They can be obtained for research purposes that are covered by §13d of the Public Administration Act by sending an application to the Norwegian Directorate of Health (no standardized procedure) or from the Norwegian Institute of Public Health (https://www.fhi.no/en/op/data-access-from-health-registries-health-studies-and-biobanks/norwegian-prescription-database/Access-data-norpd/) though we ourselves obtained it directly from the Norwegian Directorate of Health. 
•	The data on wholesale prices are also proprietary, and can be obtained from the Norwegian Institute of Public Health through a standardized application procedure (available on their webpages). 
*/

/* 9 molecules tablets for which there are PI and no generics  and match on strength */

egen month=group(date)
gen year=2004+int((month-0.5)/12)
gen quarter=int((month-0.5)/3)


keep if atccode=="C10AA05" /* Atorvastatin */

gen logshare=log(share)
egen share_chainid=sum(share) , by(market chainid)
gen share_inchain=share/share_chainid
gen logskct=log(share/share_chainid)
egen margin_parallel=sum(margin*parallel) , by(market chainid)
egen temp=sum(parallel) , by(market chainid)
replace margin_parallel=margin_parallel/temp if temp!=0
drop temp
egen margin_direct=sum(margin*(1-parallel)) , by(market chainid)
gen marginother=(margin_parallel*(1-parallel))+(margin_direct*parallel)
egen share_parallel=sum(share*parallel) , by(market chainid)
gen mardiff=margin-margin_parallel if parallel==0
compress
gen other_nokdd=0
gen c=0
foreach var in Czech_nokddd  Germany_nokddd  Italy_nokddd  Spain_nokddd France_nokddd  Greece_nokddd  Poland_nokddd  UK_nokddd {
replace `var'=`var'/4
replace other_nokdd=other_nokdd+`var' if `var'!=.
replace c=c+1 if `var'!=.
}
replace other_nokdd=other_nokdd/c
drop c
foreach var in Czech_nokddd  Germany_nokddd  Italy_nokddd  Spain_nokddd France_nokddd  Greece_nokddd  Poland_nokddd  UK_nokddd {
egen `var'mean=mean(`var') , by(atccode strength quarter)
replace `var'=`var'mean if `var'==.
drop `var'mean
egen `var'mean=mean(`var') , by(atccode strength year)
replace `var'=`var'mean if `var'==.
drop `var'mean
egen `var'mean=mean(`var') , by(atccode strength)
replace `var'=`var'mean if `var'==.
drop `var'mean
replace `var'=other_nokdd if `var'==.
}

xi : reg logskct margin marginother i.strength  i.month i.year*i.chainid if chainid>0 & parallel==0  ,  cl(market)
estimates store reg6, title("Log share")
global listiv="Czech_nokddd  Germany_nokddd  Italy_nokddd  Spain_nokddd France_nokddd    Poland_nokddd  UK_nokddd  nokusd nokeur nokchf nokusd nokeur nokchf"
xi : ivreg logskct (margin marginother= $listiv) i.strength  i.year*i.chainid  i.month if chainid>0 & parallel==0  , cl(market)
estimates store reg16, title("Log share")

/* columns 3 and 4 of table 4.2 */ xi : estout  reg6 reg16  using "reduced_form_regressionsC10AA05.tex", style(tex) cells(b(fmt(3) star)  se(par fmt(3))) stats(N,fmt(%9.0g)) replace order(margin* mardi* chain*) drop(_cons i.month i.year*i.chainid i.strength i.month)

/****************************/


use "$disk:\Dropbox\parallel\data\reduced_form_data.dta" , clear
keep date nokusd nokpln nokgbp nokeur nokczk nokchf
duplicates drop
rename date olddate
gen year=int((olddate-528)/12)
gen month=int((olddate-527-year*12))
replace year=year+2004
gen date=strofreal(year)+"-0"+strofreal(month)+"-01" if month<=9
replace date=strofreal(year)+"-"+strofreal(month)+"-01" if month>9
drop olddate year month
merge 1:m date using "$disk:\Dropbox\parallel\data\parallel_presence.dta"
drop _merge
duplicates report date chainid atccode strength prodtype pi
gen price_numeric=real(price)  
count if ddd==0 & price_numeric!=.
gen year=real(substr(date,1,4))
gen month=real(substr(date,6,2))
gen Time=(year-2004)*12+month
label define dates 1 "Jan 2004"
label values Time dates
gen generic=prodtype=="GEN"
drop if prodtype=="OTC"
drop if prodtype=="UNKNOWN"
gen parallel=pi=="True"
rename gip w
compress
egen exist_generic=max(generic) , by(atccode strength date)
egen market=group(atccode strength prodtype date)
egen share_chainid=sum(ddd) , by(market chainid)
replace share_chainid=ddd/share
label variable share_chainid "Share ddd of pi or di within chain market"
gen logskct=log(share_chainid)
gen margin=price_numeric-w
egen margin_parallel=sum(margin*parallel) , by(market chainid)
egen temp=sum(parallel) , by(market chainid)
replace margin_parallel=margin_parallel/temp if temp!=0
drop temp
egen margin_direct=sum(margin*(1-parallel)) , by(market chainid)
gen marginother=(margin_parallel*(1-parallel))+(margin_direct*parallel)
egen share_parallel=sum(share*parallel) , by(market chainid)
gen mardiff=margin-margin_parallel if parallel==0
foreach i of numlist 1/3 {
qui gen chain`i'=chainid==`i'
}

/* create other_price as average price in other countries when they exist */
gen other_price=0
gen c=0
foreach var in price_czech price_france price_germany price_greece price_italy price_poland price_spain price_uk {
replace other_price=other_price+`var' if `var'!=.
replace c=c+1 if `var'!=.
}
replace other_price=other_price/c
drop c
/* replace missing other country price by yearly average, then missing by overall average, then missing by any other average */
foreach var in price_czech price_france price_germany price_greece price_italy price_poland price_spain price_uk {
qui egen `var'mean=mean(`var') , by(atccode strength prodtype year)
qui replace `var'=`var'mean if `var'==.
qui drop `var'mean
qui egen `var'mean=mean(`var') , by(atccode strength prodtype)
qui replace `var'=`var'mean if `var'==.
qui drop `var'mean
replace `var'=other_price if `var'==.
}
drop if exist_generic==1   /* keep only atc5 codes markets where there is no generic */

foreach p in  price_france price_greece price_spain  price_czech price_poland price_uk { 
gen `p'_nok=`p'*nokusd
}
foreach x in nokchf  nokczk  nokeur  nokgbp  nokpln  nokusd {
gen chain1_`x'=(chainid==1)*`x'
gen chain2_`x'=(chainid==2)*`x'
gen chain3_`x'=(chainid==3)*`x'
}
foreach p in price_czech price_france  price_greece  price_poland price_spain price_uk {  
gen exist_`p'=`p'!=.
gen nm_`p'=`p'
replace nm_`p'=0 if `p'==.   
}
compress
egen atc=group(atccode)
duplicates report chainid atccode strength date pi generic 
compress
/*****************************************/
/* Reduced form evidence */

set matsize 11000
qui reg price_czech price_france price_germany price_greece price_italy price_poland price_spain price_uk if chainid>0  & parallel==0  & logskct<0
gen sample=e(sample)
xi : xtreg logskct margin marginother i.year*i.month chain1 chain2 i.year*chain1 i.year*chain2  if   parallel==0 & logskct<0 & sample,  fe i(atc) cl(atc)
estimates store reg6, title("Log share")
xi : xtivreg logskct  (margin marginother= i.chainid*price_italy i.chainid*price_germany i.chainid|price_czech i.chainid|price_france i.chainid|price_greece i.chainid|price_poland i.chainid|price_spain i.chainid|price_uk i.chainid*nokusd i.chainid*nokeur i.chainid*nokchf i.chainid*nokusd i.chainid*nokeur i.chainid*nokchf ) i.year*i.month  i.year*chain1 i.year*chain2  if  parallel==0  & logskct<0  & sample,  fe i(atc) 
estimates store reg16, title("Log share")
xi : xtivreg logskct  (mardiff= price_czech price_france price_germany price_greece price_italy price_poland price_spain price_uk* i.chainid*nokusd i.chainid*nokeur i.chainid*nokchf i.chainid*nokusd i.chainid*nokeur i.chainid*nokchf  ) i.year*i.month i.year*chain1 i.year*chain2 chain1 chain2  if chainid>0  & parallel==0  & logskct<0 & sample, fe i(atc) 
estimates store reg18, title("Log share")

/* columns 1 and 2 of table 4.2 */ xi : estout  reg6 reg16  /* reg8 reg18 */ using "reduced_form_regressions2019.tex", style(tex)  cells(b(fmt(3) star)  se(par fmt(3))) stats(N,fmt(%9.0g)) replace order(margin* mardi* chain*) drop(i.year*i.month)
/* results of reg8 reg18 are in WP version for robustness */
/***********************************/

 

use "$disk:\Dropbox\parallel\data\reduced_form_data.dta" ,clear
keep date nokusd nokpln nokgbp nokeur nokczk nokchf
duplicates drop
rename date olddate
gen year=int((olddate-528)/12)
gen month=int((olddate-527-year*12))
replace year=year+2004
gen date=strofreal(year)+"-0"+strofreal(month)+"-01" if month<=9
replace date=strofreal(year)+"-"+strofreal(month)+"-01" if month>9
drop olddate year month
merge 1:m date using "$disk:\Dropbox\parallel\data\parallel_presence.dta"
drop _merge
duplicates report date chainid atccode strength prodtype pi
gen price_numeric=real(price)  
count if ddd==0 & price_numeric!=.
gen year=real(substr(date,1,4))
gen month=real(substr(date,6,2))
gen Time=(year-2004)*12+month
label define dates 1 "Jan 2004"
label values Time dates
gen generic=prodtype=="GEN"
gen originator=prodtype=="ORG"
drop if prodtype=="OTC"
drop if prodtype=="UNKNOWN"
gen parallel=pi=="True"
rename gip w
compress
egen exist_generic=max(generic) , by(atccode strength date)
egen market=group(atccode strength prodtype date)
egen share_chainid=sum(ddd) , by(market chainid)
replace share_chainid=ddd/share
label variable share_chainid "Share ddd of pi or di within chain market"
gen logskct=log(share_chainid)
gen margin=price_numeric-w
egen margin_parallel=sum(margin*parallel) , by(market chainid)
egen temp=sum(parallel) , by(market chainid)
replace margin_parallel=margin_parallel/temp if temp!=0
drop temp
egen margin_direct=sum(margin*(1-parallel)) , by(market chainid)
gen marginother=(margin_parallel*(1-parallel))+(margin_direct*parallel)
egen share_parallel=sum(share*parallel) , by(market chainid)
gen mardiff=margin-margin_parallel if parallel==0
compress
foreach i of numlist 1/3 {
qui gen chain`i'=chainid==`i'
}
egen parchainmarket=max(parallel) , by(market chainid)
label variable parchainmarket  "Chain carries parallel trade in market"
gen noparchainmarket=1-parchainmarket
/* create other_price as average price in other countries when they exist */
gen other_price=0
gen c=0
foreach var in price_czech price_france price_germany price_greece price_italy price_poland price_spain price_uk {
replace other_price=other_price+`var' if `var'!=.
replace c=c+1 if `var'!=.
}
replace other_price=other_price/c
drop c
/* replace missing other country price by yearly average, then missing by overall average, then missing by any other average */
foreach var in price_czech price_france price_germany price_greece price_italy price_poland price_spain price_uk {
qui egen `var'mean=mean(`var') , by(atccode strength prodtype year)
qui replace `var'=`var'mean if `var'==.
qui drop `var'mean
qui egen `var'mean=mean(`var') , by(atccode strength prodtype)
qui replace `var'=`var'mean if `var'==.
qui drop `var'mean
replace `var'=other_price if `var'==.
}
drop if exist_generic==1   /* keep only atc5 codes markets where there is no generic */
egen presence_PI_chain=max(parallel), by(market chainid)
egen presence_PI_market=max(parallel), by(market)
egen tag_market=tag(market)
egen tag_market_chain=tag(market chainid)
egen prod=group(atccode strength)
egen mean_price_numeric=mean(price_numeric), by(atccode strength market)
foreach p in  price_france price_greece price_spain  price_czech price_poland price_uk {  
gen `p'_nok=`p'*nokusd
}
foreach x in nokchf  nokczk  nokeur  nokgbp  nokpln  nokusd {
gen chain1_`x'=(chainid==1)*`x'
gen chain2_`x'=(chainid==2)*`x'
gen chain3_`x'=(chainid==3)*`x'
}
foreach p in price_czech price_france  price_greece  price_poland price_spain price_uk { / 
gen exist_`p'=`p'!=.
gen nm_`p'=`p'
replace nm_`p'=0 if `p'==.   
}
compress
egen atc=group(atccode)
duplicates report chainid atccode strength date pi generic 

/*****************************************/

xi: logit  presence_PI_market mean_price_numeric price_czech price_france price_greece price_poland price_spain price_uk  i.month*i.year  if tag_market
distinct prod if e(sample)
distinct atccode if e(sample)
estimates store logit2, title("PI entry")
xi: clogit  presence_PI_market mean_price_numeric price_czech price_france price_greece price_poland price_spain price_uk  i.month*i.year   if tag_market, group(atccode) 
distinct prod if e(sample)
distinct atccode if e(sample)
estimates store logit6, title("PI entry")
xi: logit  presence_PI_chain price_numeric price_czech price_france price_greece price_poland price_spain price_uk i.chainid i.month*i.year  if tag_market_chain
distinct prod if e(sample)
distinct atccode if e(sample)
estimates store logit8, title("PI chain entry")
xi: clogit  presence_PI_chain price_numeric  price_czech price_france price_greece price_poland price_spain price_uk  i.chainid  i.month*i.year  if tag_market_chain, group(atccode) 
distinct prod if e(sample)
distinct atccode if e(sample)
estimates store logit12, title("PI chain entry")
/* table A.5 */xi : estout logit2 logit6 using "logit_entry_PI_market.tex", style(tex) cells(b(fmt(3) star)  se(par fmt(3))) stats(N,fmt(%9.0g)) replace 
/* table A.4 */xi : estout logit8 logit12 using "logit_entry_PI_chain.tex", style(tex)  cells(b(fmt(3) star)  se(par fmt(3))) stats(N,fmt(%9.0g)) replace 


/**************************************/
/* Effect of PI on pharmacist profit */

gen profit=margin*ddd
egen tot_profit_atc=sum(profit) , by(atccode strength chainid date)
egen avg_margin_atc=sum(ddd) , by(atccode strength chainid date)
replace avg_margin_atc=tot_profit_atc/avg_margin_atc
gen log_avg_margin_atc=log(avg_margin_atc)
gen log_tot_profit_atc=log(tot_profit_atc)

xi: reg log_tot_profit_atc  presence_PI_chain  i.chainid*i.year i.chainid*i.month i.year*i.month  if tag_market_chain
estimates store prof1, title("Log profit")
xi: xtreg log_tot_profit_atc presence_PI_chain i.chainid*i.year i.chainid*i.month i.year*i.month   if tag_market_chain , i(prod) fe 
estimates store prof2, title("Log profit")
xi: xtivreg log_tot_profit_atc (presence_PI_chain = exist_price_* nm_price_* i.chainid*nokusd i.chainid*nokeur i.chainid*nokchf i.chainid*nokusd i.chainid*nokeur i.chainid*nokchf)  i.chainid*i.month i.year*i.month  if tag_market_chain , i(prod) fe
estimates store prof6, title("Log profit")
distinct prod if e(sample)

xi: reg log_avg_margin_atc  presence_PI_chain  i.chainid*i.year i.chainid*i.month i.year*i.month  if tag_market_chain
estimates store marg1, title("Log margin")
xi: xtreg log_avg_margin_atc presence_PI_chain i.chainid*i.year i.chainid*i.month i.year*i.month   if tag_market_chain , i(prod) fe
estimates store marg2, title("Log margin")
xi: xtivreg log_avg_margin_atc (presence_PI_chain = exist_price_* nm_price_* i.chainid*nokusd i.chainid*nokeur i.chainid*nokchf i.chainid*nokusd i.chainid*nokeur i.chainid*nokchf) i.chainid*i.year i.chainid*i.month i.year*i.month  if tag_market_chain , i(prod) fe
estimates store marg6, title("Log margin")
distinct prod if e(sample)

/*table 7.1 */
xi : estout prof1 prof2  prof6 using "reduced_form_profits.tex", style(tex)  cells(b(fmt(3) star)  se(par fmt(3))) stats(N,fmt(%9.0g)) replace  drop(i.chainid*i.year i.chainid*i.month i.year*i.month)
xi : estout marg1 marg2  marg6 using "reduced_form_margins.tex", style(tex)  cells(b(fmt(3) star)  se(par fmt(3))) stats(N,fmt(%9.0g)) replace  drop(i.chainid*i.year i.chainid*i.month i.year*i.month)
































