#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
@author: Morten Sæthre

Paper: "On the Role of Parallel Trade on Manufacturers and Retailers Profits in the Pharmaceutical Sector"
Authors: Pierre Dubois (TSE) and Morten Saethre (NHH)

Calculate transition probabilities of individual choices between consecutive 
choices
(Online appendix, Table A.1)
"""

#%% SETUP

import pandas as pd

pd.options.io.parquet.engine = 'fastparquet'

# Directories
rootdir = '/home/morten/'
projectroot = f'{rootdir}projects/parallel/'
datadir = f'{projectroot}data/'
tabfigdir = f'{projectroot}tabfig/'



#%% LOAD DATA

print("Loading data")
indchoices = pd.read_parquet(f'{datadir}individual.pq')


#%% MAKe TRANSITION MATRIX
# Get individual choices, sorted
indchoices = indchoices.set_index(['patid', 'date']).sort_index()
# Lag individual choices
choicelag = indchoices.groupby('patid')[['chainid', 'parallel', 'choiceid']].shift(1)

# 2x2 previous vs next period choice, number of cases
v = 'choiceid'
nmat = (pd.get_dummies(choicelag[v]).astype(int).T
        .dot(pd.get_dummies(indchoices[v]).astype(int))
       )

# Divide by number of previous period choice (transition frequencies)
tmat = nmat.div(nmat.sum(1), axis=0)

# Set readable index
tempix = pd.MultiIndex.from_product(([1, 2, 3], ['DI', 'PI']),
                                    names=['Chain ID', 'Type'])
tmat.index = tempix
tmat.columns = tempix

# To LaTeX
print(tmat.round(2).to_latex())